@@ -174,6 +174,7 @@ gboolean g_at_result_iter_next_hexstring(GAtResultIter *iter,
 	len = strlen(line);
 
 	pos = iter->line_pos;
+	bufpos = iter->buf + pos;
 
 	/* Omitted string */
 	if (line[pos] == ',') {
@@ -192,7 +193,7 @@ gboolean g_at_result_iter_next_hexstring(GAtResultIter *iter,
 
 	*length = (end - pos) / 2;
 
-	for (bufpos = iter->buf + pos; pos < end; pos += 2)
+	for (; pos < end; pos += 2)
 		sscanf(line + pos, "%02hhx", bufpos++);
 
 out:
@@ -273,15 +274,12 @@ gboolean g_at_result_iter_next_range(GAtResultIter *iter, gint *min, gint *max)
 	if (pos == end)
 		return FALSE;
 
-	if (line[end] == ',') {
+	if (line[end] != '-') {
 		high = low;
 		goto out;
 	}
 
-	if (line[end] == '-')
-		pos = end = end + 1;
-	else
-		return FALSE;
+	pos = end = end + 1;
 
 	while (line[end] >= '0' && line[end] <= '9') {
 		high = high * 10 + (int)(line[end] - '0');
