@@ -40,6 +40,7 @@ DBusMessage *__connman_error_not_implemented(DBusMessage *msg);
 DBusMessage *__connman_error_no_carrier(DBusMessage *msg);
 DBusMessage *__connman_error_in_progress(DBusMessage *msg);
 DBusMessage *__connman_error_already_connected(DBusMessage *msg);
+DBusMessage *__connman_error_not_connected(DBusMessage *msg);
 DBusMessage *__connman_error_operation_aborted(DBusMessage *msg);
 DBusMessage *__connman_error_operation_timeout(DBusMessage *msg);
 DBusMessage *__connman_error_invalid_service(DBusMessage *msg);
@@ -63,7 +64,7 @@ void __connman_profile_list(DBusMessageIter *iter);
 const char *__connman_profile_active_ident(void);
 const char *__connman_profile_active_path(void);
 
-void __connman_profile_changed(void);
+void __connman_profile_changed(gboolean delayed);
 
 #include <connman/log.h>
 
@@ -102,6 +103,10 @@ int __connman_ipconfig_save(struct connman_ipconfig *ipconfig,
 
 #include <connman/inet.h>
 
+enum connman_device_type __connman_inet_get_device_type(int index);
+
+#include <connman/wifi.h>
+
 #include <connman/rfkill.h>
 
 int __connman_rfkill_init(void);
@@ -160,6 +165,11 @@ struct connman_device *__connman_element_get_device(struct connman_element *elem
 const char *__connman_element_get_device_path(struct connman_element *element);
 const char *__connman_element_get_network_path(struct connman_element *element);
 
+struct connman_device *__connman_element_find_device(enum connman_device_type type);
+int __connman_element_request_scan(enum connman_device_type type);
+int __connman_element_enable_technology(enum connman_device_type type);
+int __connman_element_disable_technology(enum connman_device_type type);
+
 const char *__connman_element_type2string(enum connman_element_type type);
 
 static inline void __connman_element_lock(struct connman_element *element)
@@ -175,36 +185,18 @@ int __connman_element_append_ipv4(struct connman_element *element,
 int __connman_element_set_ipv4(struct connman_element *element,
 				const char *name, DBusMessageIter *value);
 
-int __connman_detect_init(void);
-void __connman_detect_cleanup(void);
-
 int __connman_ipv4_init(void);
 void __connman_ipv4_cleanup(void);
 
 int __connman_connection_init(void);
 void __connman_connection_cleanup(void);
 
-void __connman_connection_update_gateway(void);
+gboolean __connman_connection_update_gateway(void);
 
-#ifdef HAVE_UDEV
 int __connman_udev_init(void);
 void __connman_udev_cleanup(void);
 char *__connman_udev_get_devtype(const char *ifname);
-#else
-static inline int __connman_udev_init(void)
-{
-	return 0;
-}
-
-static inline void __connman_udev_cleanup(void)
-{
-}
-
-static inline char *__connman_udev_get_devtype(const char *ifname)
-{
-	return NULL;
-}
-#endif
+char *__connman_udev_get_mbm_devnode(const char *ifname);
 
 #include <connman/device.h>
 
@@ -216,7 +208,11 @@ void __connman_device_decrease_connections(struct connman_device *device);
 
 void __connman_device_set_network(struct connman_device *device,
 					struct connman_network *network);
+void __connman_device_cleanup_networks(struct connman_device *device);
 
+int __connman_device_scan(struct connman_device *device);
+int __connman_device_enable(struct connman_device *device);
+int __connman_device_disable(struct connman_device *device);
 int __connman_device_connect(struct connman_device *device);
 int __connman_device_disconnect(struct connman_device *device);
 
@@ -246,6 +242,7 @@ connman_bool_t __connman_network_has_driver(struct connman_network *network);
 const char *__connman_network_get_type(struct connman_network *network);
 const char *__connman_network_get_group(struct connman_network *network);
 const char *__connman_network_get_ident(struct connman_network *network);
+connman_bool_t __connman_network_get_weakness(struct connman_network *network);
 
 int __connman_profile_add_network(struct connman_network *network);
 int __connman_profile_remove_network(struct connman_network *network);
@@ -261,9 +258,11 @@ void __connman_service_put(struct connman_service *service);
 
 struct connman_service *__connman_service_lookup_from_device(struct connman_device *device);
 struct connman_service *__connman_service_create_from_device(struct connman_device *device);
+void __connman_service_remove_from_device(struct connman_device *device);
 
 struct connman_service *__connman_service_lookup_from_network(struct connman_network *network);
 struct connman_service *__connman_service_create_from_network(struct connman_network *network);
+void __connman_service_remove_from_network(struct connman_network *network);
 
 unsigned int __connman_service_get_order(struct connman_service *service);
 
@@ -275,11 +274,20 @@ int __connman_service_indicate_error(struct connman_service *service,
 					enum connman_service_error error);
 int __connman_service_indicate_default(struct connman_service *service);
 
+int __connman_service_connect(struct connman_service *service);
+int __connman_service_disconnect(struct connman_service *service);
+int __connman_service_create_and_connect(DBusMessage *msg);
+void __connman_service_auto_connect(void);
+
 #include <connman/notifier.h>
 
 int __connman_notifier_init(void);
 void __connman_notifier_cleanup(void);
 
+void __connman_notifier_device_type_list(gboolean powered,
+						DBusMessageIter *iter);
+void __connman_notifier_device_type_register(enum connman_device_type type);
+void __connman_notifier_device_type_unregister(enum connman_device_type type);
 void __connman_notifier_device_type_increase(enum connman_device_type type);
 void __connman_notifier_device_type_decrease(enum connman_device_type type);
 void __connman_notifier_offline_mode(connman_bool_t enabled);
