@@ -588,9 +588,10 @@ static DBusMessage *connect_service(DBusConnection *conn,
 	iter = g_sequence_get_begin_iter(service_list);
 
 	while (g_sequence_iter_is_end(iter) == FALSE) {
-		struct connman_service *service = g_sequence_get(iter);
+		struct connman_service *temp = g_sequence_get(iter);
 
-		if (is_connecting(service) == TRUE)
+		if (service->type == temp->type &&
+					is_connecting(temp) == TRUE)
 			return __connman_error_in_progress(msg);
 
 		iter = g_sequence_iter_next(iter);
@@ -626,9 +627,6 @@ static DBusMessage *disconnect_service(DBusConnection *conn,
 
 	DBG("service %p", service);
 
-	if (service->pending != NULL)
-		reply_pending(service, ECONNABORTED);
-
 	service->ignore = TRUE;
 
 	err = __connman_service_disconnect(service);
@@ -754,10 +752,10 @@ static void service_free(gpointer user_data)
 
 	DBG("service %p", service);
 
-	g_hash_table_remove(service_hash, service->identifier);
-
 	reply_pending(service, ENOENT);
 
+	g_hash_table_remove(service_hash, service->identifier);
+
 	service->path = NULL;
 
 	if (path != NULL) {
@@ -795,8 +793,6 @@ void __connman_service_put(struct connman_service *service)
 
 		iter = g_hash_table_lookup(service_hash, service->identifier);
 		if (iter != NULL) {
-			reply_pending(service, ENOENT);
-
 			__connman_service_disconnect(service);
 
 			service->state = CONNMAN_SERVICE_STATE_FAILURE;
@@ -1108,6 +1104,8 @@ int __connman_service_disconnect(struct connman_service *service)
 
 	DBG("service %p", service);
 
+	reply_pending(service, ECONNABORTED);
+
 	if (service->network != NULL) {
 		err = __connman_network_disconnect(service->network);
 	} else if (service->device != NULL) {
